@@ -6,11 +6,14 @@
 VibrationManager::VibrationManager(QObject *parent)
     : QObject{parent}
 {
-    const auto objectPath = QStringLiteral("/com/lomiri/hfd");
-    m_interface = new com::lomiri::hfd::Vibrator("com.lomiri.hfd", objectPath, QDBusConnection::systemBus(), this);
 }
 
 void VibrationManager::vibrate(int durationMs)
 {
+    // Only create interface when needed.
+    if (!m_interface) {
+        const auto objectPath = QStringLiteral("/com/lomiri/hfd");
+        m_interface = new com::lomiri::hfd::Vibrator("com.lomiri.hfd", objectPath, QDBusConnection::systemBus(), this);
+    }
     m_interface->vibrate(durationMs);
 }
