@@ -120,13 +120,32 @@ void HomeScreenState::init()
         Q_EMIT pageColumnsChanged();
     });
 
-    connect(this, &HomeScreenState::pageWidthChanged, this, &HomeScreenState::calculatePageContentWidth);
-    connect(this, &HomeScreenState::pageHeightChanged, this, &HomeScreenState::calculatePageContentHeight);
+    connect(this, &HomeScreenState::pageWidthChanged, [this]() {
+        calculatePageContentWidth();
+        calculateFolderGridLength();
+    });
+    connect(this, &HomeScreenState::pageHeightChanged, [this]() {
+        calculatePageContentHeight();
+        calculateFolderGridLength();
+    });
+    connect(this, &HomeScreenState::pageContentWidthChanged, [this]() {
+        calculatePageCellWidth();
+        calculateFolderGridLength();
+    });
+    connect(this, &HomeScreenState::pageColumnsChanged, [this]() {
+        calculatePageCellWidth();
+        calculateFolderGridLength();
+    });
+    connect(this, &HomeScreenState::pageContentHeightChanged, [this]() {
+        calculatePageCellHeight();
+        calculateFolderGridLength();
+    });
+    connect(this, &HomeScreenState::pageRowsChanged, [this]() {
+        calculatePageCellHeight();
+        calculateFolderGridLength();
+    });
 
-    connect(this, &HomeScreenState::pageContentWidthChanged, this, &HomeScreenState::calculatePageCellWidth);
-    connect(this, &HomeScreenState::pageColumnsChanged, this, &HomeScreenState::calculatePageCellWidth);
-    connect(this, &HomeScreenState::pageContentHeightChanged, this, &HomeScreenState::calculatePageCellHeight);
-    connect(this, &HomeScreenState::pageRowsChanged, this, &HomeScreenState::calculatePageCellHeight);
+    connect(m_homeScreen->folioSettings(), &FolioSettings::delegateIconSizeChanged, this, &HomeScreenState::calculateFolderGridLength);
 
     connect(this, &HomeScreenState::viewWidthChanged, this, [this]() {
         Q_EMIT favouritesBarLocationChanged();
@@ -316,7 +335,8 @@ void HomeScreenState::setPageWidth(qreal pageWidth)
         Q_EMIT pageWidthChanged();
 
         // make sure we snap
-        snapPage();
+        goToPage(m_pageNum, true);
+        goToFolderPage(m_folderPageNum, true);
     }
 }
 
@@ -510,6 +530,22 @@ void HomeScreenState::setCurrentFolder(FolioApplicationFolder *folder)
     }
 }
 
+int HomeScreenState::folderGridLength() const
+{
+    return m_folderGridLength;
+}
+
+void HomeScreenState::calculateFolderGridLength()
+{
+    const int folderGridLength = std::max(2, qRound(std::min(m_viewWidth, m_viewHeight) * 0.6 / m_homeScreen->folioSettings()->delegateIconSize() * 0.6));
+
+    if (m_folderGridLength != folderGridLength) {
+        m_folderGridLength = folderGridLength;
+        Q_EMIT folderGridLengthChanged();
+        goToFolderPage(m_folderPageNum, true);
+    }
+}
+
 qreal HomeScreenState::settingsOpenProgress()
 {
     return m_settingsOpenProgress;
@@ -667,14 +703,12 @@ QPointF HomeScreenState::getFolderDelegateScreenPosition(int position)
         return {0, 0};
     }
     auto pos = m_currentFolder->applications()->getDelegatePosition(position);
+
     qreal x = pos.x() + (m_viewWidth - m_viewLeftPadding - m_viewRightPadding - m_folderPageWidth) / 2;
     qreal y = pos.y() + (m_viewHeight - m_viewTopPadding - m_viewBottomPadding - m_folderPageHeight) / 2;
     x += m_viewLeftPadding;
     y += m_viewTopPadding;
 
-    // adjust for the current page
-    x -= currentFolderPage() * m_folderPageWidth;
-
     return {x, y};
 }
 
@@ -712,29 +746,7 @@ void HomeScreenState::closeSearchWidget()
     m_closeSearchWidgetAnim->start();
 }
 
-void HomeScreenState::snapPage()
-{
-    const int numOfPages = m_homeScreen->pageListModel()->rowCount();
-
-    const int leftPage = qBound(0.0, (m_pageViewX / m_pageWidth), numOfPages - 1.0);
-    const qreal leftPagePos = -leftPage * m_pageWidth;
-
-    if (leftPage == numOfPages + 1) {
-        // if we are past the last page
-        goToPage(leftPage);
-    } else {
-        const qreal rightPagePos = leftPagePos - m_pageWidth;
-
-        // go to the closer page (right or left)
-        if (qAbs(rightPagePos - m_pageViewX) < qAbs(leftPagePos - m_pageViewX)) {
-            goToPage(leftPage + 1);
-        } else {
-            goToPage(leftPage);
-        }
-    }
-}
-
-void HomeScreenState::goToPage(int page)
+void HomeScreenState::goToPage(int page, bool snap)
 {
     if (page < 0) {
         page = 0;
@@ -747,12 +759,17 @@ void HomeScreenState::goToPage(int page)
 
     setCurrentPage(page);
 
-    m_pageAnim->setStartValue(m_pageViewX);
+    if (snap) {
+        // Skip the animation and go straight to the intended page
+        m_pageAnim->setStartValue(-page * m_pageWidth);
+    } else {
+        m_pageAnim->setStartValue(m_pageViewX);
+    }
     m_pageAnim->setEndValue(-page * m_pageWidth);
     m_pageAnim->start();
 }
 
-void HomeScreenState::goToFolderPage(int page)
+void HomeScreenState::goToFolderPage(int page, bool snap)
 {
     if (!m_currentFolder) {
         return;
@@ -770,7 +787,12 @@ void HomeScreenState::goToFolderPage(int page)
     m_folderPageNum = page;
     Q_EMIT folderPageNumChanged();
 
-    m_folderPageAnim->setStartValue(m_folderViewX);
+    if (snap) {
+        // Skip the animation and go straight to the intended page
+        m_folderPageAnim->setStartValue(-page * m_folderPageWidth);
+    } else {
+        m_folderPageAnim->setStartValue(m_folderViewX);
+    }
     m_folderPageAnim->setEndValue(-page * m_folderPageWidth);
     m_folderPageAnim->start();
 }
@@ -914,9 +936,9 @@ void HomeScreenState::swipeEnded()
 
         // m_movingRight refers to finger movement
         if (m_movingRight || m_pageViewX > 0) {
-            goToPage(page);
+            goToPage(page, false);
         } else {
-            goToPage(page + 1);
+            goToPage(page + 1, false);
         }
         break;
     }
@@ -925,9 +947,9 @@ void HomeScreenState::swipeEnded()
 
         // m_movingRight refers to finger movement
         if (m_movingRight || m_folderViewX > 0) {
-            goToFolderPage(page);
+            goToFolderPage(page, false);
         } else {
-            goToFolderPage(page + 1);
+            goToFolderPage(page + 1, false);
         }
         break;
     }
